@@ -15,7 +15,12 @@ import re
 import socket
 import subprocess
 import uuid
+import warnings
 
+# See https://github.com/calkit/calkit/issues/346
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=UserWarning)
+    import checksumdir
 import psutil
 import requests
 
@@ -309,8 +314,11 @@ def check_system_deps(
             if "docker" not in deps:
                 deps.append("docker")
             deps.append({"MATLAB_LICENSE_SERVER": {"kind": "env-var"}})
-        elif kind == "julia" and "julia" not in deps:
-            deps.append("julia")
+        elif kind == "julia":
+            if "julia" not in deps:
+                deps.append("julia")
+            if "juliaup" not in deps:
+                deps.append("juliaup")
     for dep in deps:
         if isinstance(dep, dict):
             keys = list(dep.keys())
@@ -562,9 +570,19 @@ def get_system_info() -> dict:
         "uv",
         "pixi",
         "Rscript",
+        "juliaup",
         "julia",
     ]:
         system_info[f"{dep}_version"] = get_dep_version(dep)
     system_info_str = json.dumps(system_info, sort_keys=True).encode()
     system_info["id"] = hashlib.sha1(system_info_str).hexdigest()
     return system_info
+
+
+def get_md5(path: str, exclude_files: list[str] | None = None) -> str:
+    if os.path.isdir(path):
+        return checksumdir.dirhash(path, excluded_files=exclude_files)
+    else:
+        with open(path) as f:
+            content = f.read()
+        return hashlib.md5(content.encode()).hexdigest()
